@@ -26,8 +26,9 @@
 `pofind` <-
 function(data, outcome = "", conditions = "", relation = "necessity", ...) {
     if (missing(data)) {
-        cat("\n")
-        stop(simpleError("Data is missing.\n\n"))
+        admisc::stopError(
+            "Data is missing."
+        )
     }
     funargs <- lapply(match.call(), deparse)
     outcome <- admisc::recreate(substitute(outcome), colnames(data))
@@ -44,8 +45,9 @@ function(data, outcome = "", conditions = "", relation = "necessity", ...) {
                     nms <- colnames(data)
                     cs <- unlist(strsplit(conditions, split = ":"))
                     if (!all(is.element(cs, nms))) {
-                        cat(enter)
-                        stop(simpleError(paste0("Inexisting condition(s) in the sequence.", enter, enter)))
+                        admisc::stopError(
+                            "Inexisting condition(s) in the sequence."
+                        )
                     }
                     conditions <- nms[seq(which(nms == cs[1]), which(nms == cs[2]))]
                 }
@@ -53,8 +55,9 @@ function(data, outcome = "", conditions = "", relation = "necessity", ...) {
         }
     }
     if (identical(outcome, "")) {
-        cat("\n")
-        stop(simpleError("The outcome is missing.\n\n"))
+        admisc::stopError(
+            "The outcome is missing."
+        )
     }
     if (is.matrix(data)) {
         data <- as.data.frame(data)
@@ -76,8 +79,9 @@ function(data, outcome = "", conditions = "", relation = "necessity", ...) {
     }
     outcome <- admisc::notilde(outcome)
     if (!is.element(outcome, colnames(data))) {
-        cat("\n")
-        stop(simpleError("Outcome not found in the data.\n\n"))
+        admisc::stopError(
+            "Outcome not found in the data."
+        )
     }
     if (identical(conditions, "")) {
         conditions <- setdiff(colnames(data), outcome)
@@ -98,25 +102,39 @@ function(data, outcome = "", conditions = "", relation = "necessity", ...) {
     if (any(noflevels > 2)) { 
         expression <- paste(unlist(lapply(seq(length(conditions)), function(x) {
             values <- sort(unique(data[, conditions[x]]))
-            return(paste(conditions[x], "[", values, "]", sep = ""))
+            return(
+                paste(conditions[x], "[", values, "]", sep = "")
+            )
         })), collapse = "+")
     }
     else {
         negconditions <- paste("~", conditions, sep = "")
-        expression <- paste(negconditions, conditions, sep = "+", collapse = "+")
+        expression <- paste(
+            negconditions,
+            conditions,
+            sep = "+",
+            collapse = "+"
+        )
     }
-    pofargs <- list(setms = expression,
-                    outcome = origoutcome,
-                    data = data,
-                    relation = relation,
-                    ... = ...)
+    pofargs <- list(
+        setms = expression,
+        outcome = origoutcome,
+        data = data,
+        relation = relation,
+        ... = ...
+    )
     result <- do.call(pof, pofargs)
     result$incl.cov <- result$incl.cov[-nrow(result$incl.cov), , drop = FALSE]
     result$options$setms <- result$options$setms[, -ncol(result$options$setms), drop = FALSE]
     if (is.element("covU", colnames(result$incl.cov))) {
         result$incl.cov <- result$incl.cov[, setdiff(colnames(result$incl.cov), "covU")]
     }
-    rownames(result$incl.cov)[seq(length(conditions))] <- paste("", rownames(result$incl.cov)[seq(length(conditions))])
+    rownames(result$incl.cov)[seq(length(conditions))] <- paste(
+        "",
+        rownames(result$incl.cov)[
+            seq(length(conditions))
+        ]
+    )
     result$options$data <- funargs$data
     return(result)
 }
