@@ -23,16 +23,19 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-`solveChart` <-
-function(chart, row.dom = FALSE, all.sol = FALSE, depth = NULL, max.comb = 0, first.min = FALSE, ...) {
+`solveChart` <- function(
+    chart, row.dom = FALSE, all.sol = FALSE, depth = NULL, max.comb = 0,
+    first.min = FALSE, ...
+) {
     if (!is.logical(chart) && length(setdiff(chart, 0:1)) > 0) {
-        cat("\n")
-        stop(simpleError("Use a logical, T/F matrix. See makeChart()'s output.\n\n"))
+        admisc::stopError(
+            "Use a logical, T/F matrix. See makeChart()'s output."
+        )
     }
-    other.args <- list(...)
-    if (is.element("min.dis", names(other.args))) {
-        if (is.logical(other.args$min.dis)) {
-            all.sol <- !other.args$min.dis
+    dots <- list(...)
+    if (is.element("min.dis", names(dots))) {
+        if (is.logical(dots$min.dis)) {
+            all.sol <- !dots$min.dis
         }
     }
     if (all.sol) {
@@ -45,13 +48,28 @@ function(chart, row.dom = FALSE, all.sol = FALSE, depth = NULL, max.comb = 0, fi
     }
     foundm <- findmin(chart, ... = ...) 
     if (foundm == 0) {
-        cat("\n")
-        stop(simpleError("The PI chart cannot be solved.\n\n"))
+        admisc::stopError(
+            "The PI chart cannot be solved."
+        )
     }
     if (is.null(depth)) depth <- 0L
-    output <- .Call("C_solveChart", matrix(as.logical(chart), nrow = nrow(chart)), all.sol, as.integer(depth), as.integer(foundm), max.comb, first.min, PACKAGE = "QCA")
+    output <- .Call(
+        "C_solveChart",
+        matrix(as.logical(chart),
+        nrow = nrow(chart)),
+        all.sol,
+        as.integer(depth),
+        as.integer(foundm),
+        max.comb,
+        first.min,
+        PACKAGE = "QCA"
+    )
     if (output[[2]]) {
-        warning(simpleWarning("The PI chart is exceedingly complex, solution(s) not guaranteed to be exhaustive.\n\n"))
+        warning(
+            simpleWarning(
+                "The PI chart is exceedingly complex, solution(s) not guaranteed to be exhaustive.\n\n"
+            )
+        )
     }
     output <- output[[1]]
     output[output == 0] <- NA
